# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/private_cloud_connection_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/private_cloud_connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.baremetal.v1alpha import private_cloud_connection_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_private__cloud__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEyandex/cloud/baremetal/v1alpha/private_cloud_connection_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a=yandex/cloud/baremetal/v1alpha/private_cloud_connection.proto\"e\n GetPrivateCloudConnectionRequest\x12\x41\n\x1bprivate_cloud_connection_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20\"\xae\x01\n!ListPrivateCloudConnectionRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"\x9e\x01\n\"ListPrivateCloudConnectionResponse\x12Y\n\x19private_cloud_connections\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.baremetal.v1alpha.PrivateCloudConnection\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\x89\x01\n#CreatePrivateCloudConnectionRequest\x12\x1b\n\x13routing_instance_id\x18\x04 \x01(\t\x12,\n\x06vrf_id\x18\x05 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x05\x08\x06\x10\xc9\x01\"K\n$CreatePrivateCloudConnectionMetadata\x12#\n\x1bprivate_cloud_connection_id\x18\x01 \x01(\t\"\xb6\x01\n#UpdatePrivateCloudConnectionRequest\x12\x41\n\x1bprivate_cloud_connection_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1b\n\x13routing_instance_id\x18\x03 \x01(\t\"K\n$UpdatePrivateCloudConnectionMetadata\x12#\n\x1bprivate_cloud_connection_id\x18\x01 \x01(\t\"h\n#DeletePrivateCloudConnectionRequest\x12\x41\n\x1bprivate_cloud_connection_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20\"K\n$DeletePrivateCloudConnectionMetadata\x12#\n\x1bprivate_cloud_connection_id\x18\x01 \x01(\t2\xb5\t\n\x1dPrivateCloudConnectionService\x12\xd1\x01\n\x03Get\x12@.yandex.cloud.baremetal.v1alpha.GetPrivateCloudConnectionRequest\x1a\x36.yandex.cloud.baremetal.v1alpha.PrivateCloudConnection\"P\x82\xd3\xe4\x93\x02J\x12H/baremetal/v1alpha/privateCloudConnections/{private_cloud_connection_id}\x12\xc1\x01\n\x04List\x12\x41.yandex.cloud.baremetal.v1alpha.ListPrivateCloudConnectionRequest\x1a\x42.yandex.cloud.baremetal.v1alpha.ListPrivateCloudConnectionResponse\"2\x82\xd3\xe4\x93\x02,\x12*/baremetal/v1alpha/privateCloudConnections\x12\xe9\x01\n\x06\x43reate\x12\x43.yandex.cloud.baremetal.v1alpha.CreatePrivateCloudConnectionRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*>\n$CreatePrivateCloudConnectionMetadata\x12\x16PrivateCloudConnection\x82\xd3\xe4\x93\x02/\"*/baremetal/v1alpha/privateCloudConnections:\x01*\x12\x88\x02\n\x06Update\x12\x43.yandex.cloud.baremetal.v1alpha.UpdatePrivateCloudConnectionRequest\x1a!.yandex.cloud.operation.Operation\"\x95\x01\xb2\xd2*>\n$UpdatePrivateCloudConnectionMetadata\x12\x16PrivateCloudConnection\x82\xd3\xe4\x93\x02M2H/baremetal/v1alpha/privateCloudConnections/{private_cloud_connection_id}:\x01*\x12\x84\x02\n\x06\x44\x65lete\x12\x43.yandex.cloud.baremetal.v1alpha.DeletePrivateCloudConnectionRequest\x1a!.yandex.cloud.operation.Operation\"\x91\x01\xb2\xd2*=\n$DeletePrivateCloudConnectionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02J*H/baremetal/v1alpha/privateCloudConnections/{private_cloud_connection_id}Br\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['private_cloud_connection_id']._loaded_options = None
  _globals['_GETPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['private_cloud_connection_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_LISTPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_LISTPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_CREATEPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['vrf_id']._loaded_options = None
  _globals['_CREATEPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['vrf_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_UPDATEPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['private_cloud_connection_id']._loaded_options = None
  _globals['_UPDATEPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['private_cloud_connection_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_DELETEPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['private_cloud_connection_id']._loaded_options = None
  _globals['_DELETEPRIVATECLOUDCONNECTIONREQUEST'].fields_by_name['private_cloud_connection_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002J\022H/baremetal/v1alpha/privateCloudConnections/{private_cloud_connection_id}'
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002,\022*/baremetal/v1alpha/privateCloudConnections'
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*>\n$CreatePrivateCloudConnectionMetadata\022\026PrivateCloudConnection\202\323\344\223\002/\"*/baremetal/v1alpha/privateCloudConnections:\001*'
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*>\n$UpdatePrivateCloudConnectionMetadata\022\026PrivateCloudConnection\202\323\344\223\002M2H/baremetal/v1alpha/privateCloudConnections/{private_cloud_connection_id}:\001*'
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PRIVATECLOUDCONNECTIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*=\n$DeletePrivateCloudConnectionMetadata\022\025google.protobuf.Empty\202\323\344\223\002J*H/baremetal/v1alpha/privateCloudConnections/{private_cloud_connection_id}'
  _globals['_GETPRIVATECLOUDCONNECTIONREQUEST']._serialized_start=337
  _globals['_GETPRIVATECLOUDCONNECTIONREQUEST']._serialized_end=438
  _globals['_LISTPRIVATECLOUDCONNECTIONREQUEST']._serialized_start=441
  _globals['_LISTPRIVATECLOUDCONNECTIONREQUEST']._serialized_end=615
  _globals['_LISTPRIVATECLOUDCONNECTIONRESPONSE']._serialized_start=618
  _globals['_LISTPRIVATECLOUDCONNECTIONRESPONSE']._serialized_end=776
  _globals['_CREATEPRIVATECLOUDCONNECTIONREQUEST']._serialized_start=779
  _globals['_CREATEPRIVATECLOUDCONNECTIONREQUEST']._serialized_end=916
  _globals['_CREATEPRIVATECLOUDCONNECTIONMETADATA']._serialized_start=918
  _globals['_CREATEPRIVATECLOUDCONNECTIONMETADATA']._serialized_end=993
  _globals['_UPDATEPRIVATECLOUDCONNECTIONREQUEST']._serialized_start=996
  _globals['_UPDATEPRIVATECLOUDCONNECTIONREQUEST']._serialized_end=1178
  _globals['_UPDATEPRIVATECLOUDCONNECTIONMETADATA']._serialized_start=1180
  _globals['_UPDATEPRIVATECLOUDCONNECTIONMETADATA']._serialized_end=1255
  _globals['_DELETEPRIVATECLOUDCONNECTIONREQUEST']._serialized_start=1257
  _globals['_DELETEPRIVATECLOUDCONNECTIONREQUEST']._serialized_end=1361
  _globals['_DELETEPRIVATECLOUDCONNECTIONMETADATA']._serialized_start=1363
  _globals['_DELETEPRIVATECLOUDCONNECTIONMETADATA']._serialized_end=1438
  _globals['_PRIVATECLOUDCONNECTIONSERVICE']._serialized_start=1441
  _globals['_PRIVATECLOUDCONNECTIONSERVICE']._serialized_end=2646
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/smartwebsecurity/v1/waf/waf_profile_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/smartwebsecurity/v1/waf/waf_profile_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartwebsecurity.v1.waf import waf_profile_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_waf_dot_waf__profile__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/smartwebsecurity/v1/waf/waf_profile_service.proto\x12$yandex.cloud.smartwebsecurity.v1.waf\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x36yandex/cloud/smartwebsecurity/v1/waf/waf_profile.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x14GetWafProfileRequest\x12\x1c\n\x0ewaf_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x16ListWafProfilesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"a\n\x17ListWafProfilesResponse\x12\x46\n\x0cwaf_profiles\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.smartwebsecurity.v1.waf.WafProfile\"\xb0\x05\n\x17\x43reateWafProfileRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12Y\n\x06labels\x18\x04 \x03(\x0b\x32I.yandex.cloud.smartwebsecurity.v1.waf.CreateWafProfileRequest.LabelsEntry\x12\x43\n\x05rules\x18\x05 \x03(\x0b\x32\x34.yandex.cloud.smartwebsecurity.v1.waf.WafProfileRule\x12V\n\x0f\x65xclusion_rules\x18\x06 \x03(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.waf.WafProfileExclusionRule\x12U\n\rcore_rule_set\x18\x07 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.CoreRuleSetH\x00\x12\x61\n\x14\x61nalyze_request_body\x18\x08 \x01(\x0b\x32\x43.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.AnalyzeRequestBody\x12U\n\trule_sets\x18\t \x03(\x0b\x32\x42.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet\x12\x1b\n\x13match_all_rule_sets\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08rule_set\"2\n\x18\x43reateWafProfileMetadata\x12\x16\n\x0ewaf_profile_id\x18\x01 \x01(\t\"\xec\x05\n\x17UpdateWafProfileRequest\x12\x1c\n\x0ewaf_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12Y\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.smartwebsecurity.v1.waf.UpdateWafProfileRequest.LabelsEntry\x12\x43\n\x05rules\x18\x06 \x03(\x0b\x32\x34.yandex.cloud.smartwebsecurity.v1.waf.WafProfileRule\x12V\n\x0f\x65xclusion_rules\x18\x07 \x03(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.waf.WafProfileExclusionRule\x12U\n\rcore_rule_set\x18\x08 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.CoreRuleSetH\x00\x12\x61\n\x14\x61nalyze_request_body\x18\t \x01(\x0b\x32\x43.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.AnalyzeRequestBody\x12U\n\trule_sets\x18\n \x03(\x0b\x32\x42.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet\x12\x1b\n\x13match_all_rule_sets\x18\x0b \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08rule_set\"2\n\x18UpdateWafProfileMetadata\x12\x16\n\x0ewaf_profile_id\x18\x01 \x01(\t\"7\n\x17\x44\x65leteWafProfileRequest\x12\x1c\n\x0ewaf_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x18\x44\x65leteWafProfileMetadata\x12\x16\n\x0ewaf_profile_id\x18\x01 \x01(\t2\xea\x07\n\x11WafProfileService\x12\xae\x01\n\x03Get\x12:.yandex.cloud.smartwebsecurity.v1.waf.GetWafProfileRequest\x1a\x30.yandex.cloud.smartwebsecurity.v1.waf.WafProfile\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/smartwebsecurity/v1/wafProfiles/{waf_profile_id}\x12\xad\x01\n\x04List\x12<.yandex.cloud.smartwebsecurity.v1.waf.ListWafProfilesRequest\x1a=.yandex.cloud.smartwebsecurity.v1.waf.ListWafProfilesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /smartwebsecurity/v1/wafProfiles\x12\xc1\x01\n\x06\x43reate\x12=.yandex.cloud.smartwebsecurity.v1.waf.CreateWafProfileRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*&\n\x18\x43reateWafProfileMetadata\x12\nWafProfile\x82\xd3\xe4\x93\x02%\" /smartwebsecurity/v1/wafProfiles:\x01*\x12\xd2\x01\n\x06Update\x12=.yandex.cloud.smartwebsecurity.v1.waf.UpdateWafProfileRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*&\n\x18UpdateWafProfileMetadata\x12\nWafProfile\x82\xd3\xe4\x93\x02\x36\x32\x31/smartwebsecurity/v1/wafProfiles/{waf_profile_id}:\x01*\x12\xda\x01\n\x06\x44\x65lete\x12=.yandex.cloud.smartwebsecurity.v1.waf.DeleteWafProfileRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*1\n\x18\x44\x65leteWafProfileMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x33*1/smartwebsecurity/v1/wafProfiles/{waf_profile_id}B\x85\x01\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurity'
  _globals['_GETWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._loaded_options = None
  _globals['_GETWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTWAFPROFILESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTWAFPROFILESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._loaded_options = None
  _globals['_UPDATEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._loaded_options = None
  _globals['_DELETEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0023\0221/smartwebsecurity/v1/wafProfiles/{waf_profile_id}'
  _globals['_WAFPROFILESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /smartwebsecurity/v1/wafProfiles'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateWafProfileMetadata\022\nWafProfile\202\323\344\223\002%\" /smartwebsecurity/v1/wafProfiles:\001*'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateWafProfileMetadata\022\nWafProfile\202\323\344\223\002621/smartwebsecurity/v1/wafProfiles/{waf_profile_id}:\001*'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteWafProfileMetadata\022\025google.protobuf.Empty\202\323\344\223\0023*1/smartwebsecurity/v1/wafProfiles/{waf_profile_id}'
  _globals['_GETWAFPROFILEREQUEST']._serialized_start=329
  _globals['_GETWAFPROFILEREQUEST']._serialized_end=381
  _globals['_LISTWAFPROFILESREQUEST']._serialized_start=383
  _globals['_LISTWAFPROFILESREQUEST']._serialized_end=432
  _globals['_LISTWAFPROFILESRESPONSE']._serialized_start=434
  _globals['_LISTWAFPROFILESRESPONSE']._serialized_end=531
  _globals['_CREATEWAFPROFILEREQUEST']._serialized_start=534
  _globals['_CREATEWAFPROFILEREQUEST']._serialized_end=1222
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_CREATEWAFPROFILEMETADATA']._serialized_start=1224
  _globals['_CREATEWAFPROFILEMETADATA']._serialized_end=1274
  _globals['_UPDATEWAFPROFILEREQUEST']._serialized_start=1277
  _globals['_UPDATEWAFPROFILEREQUEST']._serialized_end=2025
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_UPDATEWAFPROFILEMETADATA']._serialized_start=2027
  _globals['_UPDATEWAFPROFILEMETADATA']._serialized_end=2077
  _globals['_DELETEWAFPROFILEREQUEST']._serialized_start=2079
  _globals['_DELETEWAFPROFILEREQUEST']._serialized_end=2134
  _globals['_DELETEWAFPROFILEMETADATA']._serialized_start=2136
  _globals['_DELETEWAFPROFILEMETADATA']._serialized_end=2186
  _globals['_WAFPROFILESERVICE']._serialized_start=2189
  _globals['_WAFPROFILESERVICE']._serialized_end=3191
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/scan_policy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/scan_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/containerregistry/v1/scan_policy.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcf\x01\n\nScanPolicy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bregistry_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12;\n\x05rules\x18\x05 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64isabled\x18\x07 \x01(\x08\"\x95\x01\n\tScanRules\x12>\n\tpush_rule\x18\x01 \x01(\x0b\x32+.yandex.cloud.containerregistry.v1.PushRule\x12H\n\x0eschedule_rules\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.ScheduledRule\"\x86\x01\n\x08PushRule\x12h\n\x13repository_prefixes\x18\x01 \x03(\tBK\xf2\xc7\x31\x41\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\x82\xc8\x31\x02>0\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\"\xc3\x01\n\rScheduledRule\x12h\n\x13repository_prefixes\x18\x01 \x03(\tBK\xf2\xc7\x31\x41\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\x82\xc8\x31\x02>0\x12\x36\n\rrescan_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x42\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.scan_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_PUSHRULE'].fields_by_name['repository_prefixes']._loaded_options = None
  _globals['_PUSHRULE'].fields_by_name['repository_prefixes']._serialized_options = b'\362\3071A\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\202\3101\002>0'
  _globals['_SCHEDULEDRULE'].fields_by_name['repository_prefixes']._loaded_options = None
  _globals['_SCHEDULEDRULE'].fields_by_name['repository_prefixes']._serialized_options = b'\362\3071A\\*|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\202\3101\002>0'
  _globals['_SCHEDULEDRULE'].fields_by_name['rescan_period']._loaded_options = None
  _globals['_SCHEDULEDRULE'].fields_by_name['rescan_period']._serialized_options = b'\350\3071\001'
  _globals['_SCANPOLICY']._serialized_start=187
  _globals['_SCANPOLICY']._serialized_end=394
  _globals['_SCANRULES']._serialized_start=397
  _globals['_SCANRULES']._serialized_end=546
  _globals['_PUSHRULE']._serialized_start=549
  _globals['_PUSHRULE']._serialized_end=683
  _globals['_SCHEDULEDRULE']._serialized_start=686
  _globals['_SCHEDULEDRULE']._serialized_end=881
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SchedulerLinear(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_LR_FIELD_NUMBER: builtins.int
    min_lr: builtins.float
    def __init__(
        self,
        *,
        min_lr: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["min_lr", b"min_lr"]) -> None: ...

global___SchedulerLinear = SchedulerLinear

@typing.final
class SchedulerConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SchedulerConstant = SchedulerConstant

@typing.final
class SchedulerCosine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_LR_FIELD_NUMBER: builtins.int
    min_lr: builtins.float
    def __init__(
        self,
        *,
        min_lr: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["min_lr", b"min_lr"]) -> None: ...

global___SchedulerCosine = SchedulerCosine



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/vpc/v1/network_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/vpc/v1/network_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.vpc.v1 import network_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_network__pb2
from yandex.cloud.vpc.v1 import subnet_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_subnet__pb2
from yandex.cloud.vpc.v1 import security_group_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_security__group__pb2
from yandex.cloud.vpc.v1 import route_table_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/vpc/v1/network_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a!yandex/cloud/vpc/v1/network.proto\x1a yandex/cloud/vpc/v1/subnet.proto\x1a(yandex/cloud/vpc/v1/security_group.proto\x1a%yandex/cloud/vpc/v1/route_table.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListNetworksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"_\n\x14ListNetworksResponse\x12.\n\x08networks\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.vpc.v1.Network\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc9\x02\n\x14\x43reateNetworkRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x04name\x18\x02 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x82\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.CreateNetworkRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\"\xfb\x02\n\x14UpdateNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04name\x18\x03 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x82\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.UpdateNetworkRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\"{\n\x19ListNetworkSubnetsRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x1aListNetworkSubnetsResponse\x12,\n\x07subnets\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.vpc.v1.Subnet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x82\x01\n ListNetworkSecurityGroupsRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"y\n!ListNetworkSecurityGroupsResponse\x12;\n\x0fsecurity_groups\x18\x01 \x03(\x0b\x32\".yandex.cloud.vpc.v1.SecurityGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x7f\n\x1dListNetworkRouteTablesRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"p\n\x1eListNetworkRouteTablesResponse\x12\x35\n\x0croute_tables\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.vpc.v1.RouteTable\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1cListNetworkOperationsRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListNetworkOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveNetworkRequest\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13MoveNetworkMetadata\x12\x12\n\nnetwork_id\x18\x01 \x01(\t2\xce\x0c\n\x0eNetworkService\x12r\n\x03Get\x12&.yandex.cloud.vpc.v1.GetNetworkRequest\x1a\x1c.yandex.cloud.vpc.v1.Network\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/vpc/v1/networks/{network_id}\x12u\n\x04List\x12(.yandex.cloud.vpc.v1.ListNetworksRequest\x1a).yandex.cloud.vpc.v1.ListNetworksResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/vpc/v1/networks\x12\x97\x01\n\x06\x43reate\x12).yandex.cloud.vpc.v1.CreateNetworkRequest\x1a!.yandex.cloud.operation.Operation\"?\xb2\xd2* \n\x15\x43reateNetworkMetadata\x12\x07Network\x82\xd3\xe4\x93\x02\x15\"\x10/vpc/v1/networks:\x01*\x12\xa4\x01\n\x06Update\x12).yandex.cloud.vpc.v1.UpdateNetworkRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2* \n\x15UpdateNetworkMetadata\x12\x07Network\x82\xd3\xe4\x93\x02\"2\x1d/vpc/v1/networks/{network_id}:\x01*\x12\xaf\x01\n\x06\x44\x65lete\x12).yandex.cloud.vpc.v1.DeleteNetworkRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*.\n\x15\x44\x65leteNetworkMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f*\x1d/vpc/v1/networks/{network_id}\x12\x9d\x01\n\x0bListSubnets\x12..yandex.cloud.vpc.v1.ListNetworkSubnetsRequest\x1a/.yandex.cloud.vpc.v1.ListNetworkSubnetsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/vpc/v1/networks/{network_id}/subnets\x12\xba\x01\n\x12ListSecurityGroups\x12\x35.yandex.cloud.vpc.v1.ListNetworkSecurityGroupsRequest\x1a\x36.yandex.cloud.vpc.v1.ListNetworkSecurityGroupsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/vpc/v1/networks/{network_id}/security_groups\x12\xae\x01\n\x0fListRouteTables\x12\x32.yandex.cloud.vpc.v1.ListNetworkRouteTablesRequest\x1a\x33.yandex.cloud.vpc.v1.ListNetworkRouteTablesResponse\"2\x82\xd3\xe4\x93\x02,\x12*/vpc/v1/networks/{network_id}/route_tables\x12\xa9\x01\n\x0eListOperations\x12\x31.yandex.cloud.vpc.v1.ListNetworkOperationsRequest\x1a\x32.yandex.cloud.vpc.v1.ListNetworkOperationsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/vpc/v1/networks/{network_id}/operations\x12\xa3\x01\n\x04Move\x12\'.yandex.cloud.vpc.v1.MoveNetworkRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*\x1e\n\x13MoveNetworkMetadata\x12\x07Network\x82\xd3\xe4\x93\x02\'\"\"/vpc/v1/networks/{network_id}:move:\x01*BV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.network_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _globals['_GETNETWORKREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_GETNETWORKREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTNETWORKSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATENETWORKREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATENETWORKREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATENETWORKREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATENETWORKREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATENETWORKREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATENETWORKREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _globals['_CREATENETWORKREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATENETWORKREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATENETWORKREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATENETWORKREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATENETWORKREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATENETWORKREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATENETWORKREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETENETWORKREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_DELETENETWORKREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTNETWORKSUBNETSREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_LISTNETWORKSUBNETSREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTNETWORKSUBNETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNETWORKSUBNETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTNETWORKSUBNETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNETWORKSUBNETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTNETWORKROUTETABLESREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_LISTNETWORKROUTETABLESREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTNETWORKROUTETABLESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNETWORKROUTETABLESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTNETWORKROUTETABLESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNETWORKROUTETABLESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTNETWORKOPERATIONSREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_LISTNETWORKOPERATIONSREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTNETWORKOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTNETWORKOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTNETWORKOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTNETWORKOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_MOVENETWORKREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_MOVENETWORKREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVENETWORKREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVENETWORKREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_NETWORKSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/vpc/v1/networks/{network_id}'
  _globals['_NETWORKSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\022\022\020/vpc/v1/networks'
  _globals['_NETWORKSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateNetworkMetadata\022\007Network\202\323\344\223\002\025\"\020/vpc/v1/networks:\001*'
  _globals['_NETWORKSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateNetworkMetadata\022\007Network\202\323\344\223\002\"2\035/vpc/v1/networks/{network_id}:\001*'
  _globals['_NETWORKSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteNetworkMetadata\022\025google.protobuf.Empty\202\323\344\223\002\037*\035/vpc/v1/networks/{network_id}'
  _globals['_NETWORKSERVICE'].methods_by_name['ListSubnets']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['ListSubnets']._serialized_options = b'\202\323\344\223\002\'\022%/vpc/v1/networks/{network_id}/subnets'
  _globals['_NETWORKSERVICE'].methods_by_name['ListSecurityGroups']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['ListSecurityGroups']._serialized_options = b'\202\323\344\223\002/\022-/vpc/v1/networks/{network_id}/security_groups'
  _globals['_NETWORKSERVICE'].methods_by_name['ListRouteTables']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['ListRouteTables']._serialized_options = b'\202\323\344\223\002,\022*/vpc/v1/networks/{network_id}/route_tables'
  _globals['_NETWORKSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002*\022(/vpc/v1/networks/{network_id}/operations'
  _globals['_NETWORKSERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_NETWORKSERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveNetworkMetadata\022\007Network\202\323\344\223\002\'\"\"/vpc/v1/networks/{network_id}:move:\001*'
  _globals['_GETNETWORKREQUEST']._serialized_start=385
  _globals['_GETNETWORKREQUEST']._serialized_end=438
  _globals['_LISTNETWORKSREQUEST']._serialized_start=441
  _globals['_LISTNETWORKSREQUEST']._serialized_end=585
  _globals['_LISTNETWORKSRESPONSE']._serialized_start=587
  _globals['_LISTNETWORKSRESPONSE']._serialized_end=682
  _globals['_CREATENETWORKREQUEST']._serialized_start=685
  _globals['_CREATENETWORKREQUEST']._serialized_end=1014
  _globals['_CREATENETWORKREQUEST_LABELSENTRY']._serialized_start=969
  _globals['_CREATENETWORKREQUEST_LABELSENTRY']._serialized_end=1014
  _globals['_CREATENETWORKMETADATA']._serialized_start=1016
  _globals['_CREATENETWORKMETADATA']._serialized_end=1059
  _globals['_UPDATENETWORKREQUEST']._serialized_start=1062
  _globals['_UPDATENETWORKREQUEST']._serialized_end=1441
  _globals['_UPDATENETWORKREQUEST_LABELSENTRY']._serialized_start=969
  _globals['_UPDATENETWORKREQUEST_LABELSENTRY']._serialized_end=1014
  _globals['_UPDATENETWORKMETADATA']._serialized_start=1443
  _globals['_UPDATENETWORKMETADATA']._serialized_end=1486
  _globals['_DELETENETWORKREQUEST']._serialized_start=1488
  _globals['_DELETENETWORKREQUEST']._serialized_end=1544
  _globals['_DELETENETWORKMETADATA']._serialized_start=1546
  _globals['_DELETENETWORKMETADATA']._serialized_end=1589
  _globals['_LISTNETWORKSUBNETSREQUEST']._serialized_start=1591
  _globals['_LISTNETWORKSUBNETSREQUEST']._serialized_end=1714
  _globals['_LISTNETWORKSUBNETSRESPONSE']._serialized_start=1716
  _globals['_LISTNETWORKSUBNETSRESPONSE']._serialized_end=1815
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST']._serialized_start=1818
  _globals['_LISTNETWORKSECURITYGROUPSREQUEST']._serialized_end=1948
  _globals['_LISTNETWORKSECURITYGROUPSRESPONSE']._serialized_start=1950
  _globals['_LISTNETWORKSECURITYGROUPSRESPONSE']._serialized_end=2071
  _globals['_LISTNETWORKROUTETABLESREQUEST']._serialized_start=2073
  _globals['_LISTNETWORKROUTETABLESREQUEST']._serialized_end=2200
  _globals['_LISTNETWORKROUTETABLESRESPONSE']._serialized_start=2202
  _globals['_LISTNETWORKROUTETABLESRESPONSE']._serialized_end=2314
  _globals['_LISTNETWORKOPERATIONSREQUEST']._serialized_start=2316
  _globals['_LISTNETWORKOPERATIONSREQUEST']._serialized_end=2442
  _globals['_LISTNETWORKOPERATIONSRESPONSE']._serialized_start=2444
  _globals['_LISTNETWORKOPERATIONSRESPONSE']._serialized_end=2555
  _globals['_MOVENETWORKREQUEST']._serialized_start=2557
  _globals['_MOVENETWORKREQUEST']._serialized_end=2656
  _globals['_MOVENETWORKMETADATA']._serialized_start=2658
  _globals['_MOVENETWORKMETADATA']._serialized_end=2699
  _globals['_NETWORKSERVICE']._serialized_start=2702
  _globals['_NETWORKSERVICE']._serialized_end=4316
# @@protoc_insertion_point(module_scope)



import logging
from importlib.metadata import PackageNotFoundError, version
from typing import Dict, Optional

import grpc

from yandex.cloud.endpoint.api_endpoint_service_pb2 import ListApiEndpointsRequest
from yandex.cloud.endpoint.api_endpoint_service_pb2_grpc import ApiEndpointServiceStub
from yandexcloud import _auth_plugin
from yandexcloud._auth_fabric import YC_API_ENDPOINT, get_auth_token_requester

try:
    VERSION = version("yandexcloud")
except PackageNotFoundError:
    VERSION = "0.0.0"

SDK_USER_AGENT = f"yandex-cloud-python-sdk/{VERSION}"
logger = logging.getLogger(__name__)


class Channels:
    def __init__(
        self,
        client_user_agent: Optional[str] = None,
        endpoints: Optional[Dict[str, str]] = None,
        token: Optional[str] = None,
        iam_token: Optional[str] = None,
        endpoint: Optional[str] = None,
        service_account_key: Optional[Dict[str, str]] = None,
        root_certificates: Optional[bytes] = None,
        private_key: Optional[bytes] = None,
        certificate_chain: Optional[bytes] = None,
        service_config: Optional[str] = None,
        **_: str,
    ) -> None:
        self._channel_creds = grpc.ssl_channel_credentials(
            root_certificates=root_certificates,
            private_key=private_key,
            certificate_chain=certificate_chain,
        )
        self._endpoint = endpoint if endpoint is not None else YC_API_ENDPOINT
        self._token_requester = get_auth_token_requester(
            token=token,
            service_account_key=service_account_key,
            iam_token=iam_token,
            endpoint=self._endpoint,
        )

        self._client_user_agent = client_user_agent
        self._config_endpoints = endpoints if endpoints is not None else {}
        self._endpoints: Optional[Dict[str, str]] = None
        # flake8: noqa
        self.channel_options = tuple(
            [
                ("grpc.primary_user_agent", user_agent)
                for user_agent in [self._client_user_agent, SDK_USER_AGENT]
                if user_agent is not None
            ]
            + ([("grpc.service_config", service_config)] if service_config is not None else [])
        )

    def channel(self, service: str, endpoint: Optional[str] = None, insecure: bool = False) -> grpc.Channel:
        if endpoint:
            logger.info("Using provided service %s endpoint %s", service, endpoint)
            if insecure:
                logger.info("Insecure option is ON, no IAM endpoint used for verification")
                return grpc.insecure_channel(endpoint, options=self.channel_options)
            logger.info("Insecure option is OFF,IAM endpoint %s used for verification")
            creds: grpc.ChannelCredentials = self._get_creds(self.endpoints["iam"])
            return grpc.secure_channel(endpoint, creds, options=self.channel_options)
        if service not in self._config_endpoints and insecure:
            logger.warning(
                "Unable to use insecure option for default {%s} service endpoint.\n"
                "Option is ignored. To enable it override endpoint.",
                service,
            )
        elif insecure:
            logger.info("Insecure option is ON, no IAM endpoint used for verification")
            return grpc.insecure_channel(self.endpoints[service], options=self.channel_options)

        logger.info(
            "Using endpoints from configuration, IAM %s, %s %s",
            self.endpoints["iam"],
            service,
            self.endpoints[service],
        )

        creds = self._get_creds(self.endpoints["iam"])
        if service not in self.endpoints:
            raise RuntimeError(f"Unknown service: {service}")
        return grpc.secure_channel(self.endpoints[service], creds, options=self.channel_options)

    @property
    def endpoints(self) -> Dict[str, str]:
        if self._endpoints is None:
            self._endpoints = self._get_endpoints()
            for id_, address in self._config_endpoints.items():
                logger.debug("Override service %s, endpoint %s", id_, address)
                if id_ == "iam":
                    logger.warning(
                        "Be aware `iam` service endpoint is overridden. "
                        "That can produce unexpected results in SDK calls."
                    )
                self._endpoints[id_] = address
        return self._endpoints

    def _get_endpoints(self) -> Dict[str, str]:
        unauthenticated_channel = grpc.secure_channel(self._endpoint, self._channel_creds, options=self.channel_options)
        endpoint_service = ApiEndpointServiceStub(unauthenticated_channel)
        resp = endpoint_service.List(ListApiEndpointsRequest())
        return {endpoint.id: endpoint.address for endpoint in resp.endpoints}

    def _get_creds(self, iam_endpoint: str) -> grpc.ChannelCredentials:
        plugin = _auth_plugin.Credentials(
            self._token_requester, lambda: grpc.secure_channel(iam_endpoint, creds, options=self.channel_options)
        )
        call_creds = grpc.metadata_call_credentials(plugin)
        creds = grpc.composite_channel_credentials(self._channel_creds, call_creds)
        return creds



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.baremetal.v1alpha import server_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__pb2
from yandex.cloud.baremetal.v1alpha import server_service_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/baremetal/v1alpha/server_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ServerServiceStub(object):
    """A set of methods for managing Server resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/Get',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.GetServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__pb2.Server.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/List',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/Create',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.CreateServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.BatchCreate = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/BatchCreate',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.BatchCreateServersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/Update',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.UpdateServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.PowerOff = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/PowerOff',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.PowerOffServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.PowerOn = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/PowerOn',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.PowerOnServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Reboot = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/Reboot',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.RebootServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Reinstall = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/Reinstall',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ReinstallServerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.StartProlongation = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/StartProlongation',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.StartProlongationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.StopProlongation = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/StopProlongation',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.StopProlongationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.baremetal.v1alpha.ServerService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerOperationsResponse.FromString,
                _registered_method=True)


class ServerServiceServicer(object):
    """A set of methods for managing Server resources.
    """

    def Get(self, request, context):
        """Returns the specific Server resource.

        To get the list of available Server resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Server resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a server in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCreate(self, request, context):
        """Creates multiple servers in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PowerOff(self, request, context):
        """Powers off the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PowerOn(self, request, context):
        """Powers on the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reboot(self, request, context):
        """Reboots the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reinstall(self, request, context):
        """Reinstalls the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartProlongation(self, request, context):
        """Starts prolongation of the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopProlongation(self, request, context):
        """Stops prolongation of the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.GetServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__pb2.Server.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.CreateServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'BatchCreate': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCreate,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.BatchCreateServersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.UpdateServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'PowerOff': grpc.unary_unary_rpc_method_handler(
                    servicer.PowerOff,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.PowerOffServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'PowerOn': grpc.unary_unary_rpc_method_handler(
                    servicer.PowerOn,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.PowerOnServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Reboot': grpc.unary_unary_rpc_method_handler(
                    servicer.Reboot,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.RebootServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Reinstall': grpc.unary_unary_rpc_method_handler(
                    servicer.Reinstall,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ReinstallServerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'StartProlongation': grpc.unary_unary_rpc_method_handler(
                    servicer.StartProlongation,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.StartProlongationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'StopProlongation': grpc.unary_unary_rpc_method_handler(
                    servicer.StopProlongation,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.StopProlongationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.baremetal.v1alpha.ServerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.baremetal.v1alpha.ServerService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ServerService(object):
    """A set of methods for managing Server resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/Get',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.GetServerRequest.SerializeToString,
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__pb2.Server.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/List',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerRequest.SerializeToString,
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/Create',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.CreateServerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchCreate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/BatchCreate',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.BatchCreateServersRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/Update',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.UpdateServerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PowerOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/PowerOff',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.PowerOffServerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PowerOn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/PowerOn',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.PowerOnServerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Reboot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/Reboot',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.RebootServerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Reinstall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/Reinstall',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ReinstallServerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StartProlongation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/StartProlongation',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.StartProlongationRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StopProlongation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/StopProlongation',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.StopProlongationRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.baremetal.v1alpha.ServerService/ListOperations',
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_server__service__pb2.ListServerOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.disk_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CPU(google.protobuf.message.Message):
    """CPU configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the CPU."""
    vendor: builtins.str
    """Vendor of the CPU."""
    cores: builtins.int
    """Number of cores."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        vendor: builtins.str = ...,
        cores: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cores", b"cores", "name", b"name", "vendor", b"vendor"]) -> None: ...

global___CPU = CPU

@typing.final
class DiskDriveConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DISK_COUNT_FIELD_NUMBER: builtins.int
    DISK_SIZE_GIB_FIELD_NUMBER: builtins.int
    type: yandex.cloud.baremetal.v1alpha.disk_pb2.DiskDriveType.ValueType
    """Type of the disk drive."""
    disk_count: builtins.int
    """Number of disk drives."""
    disk_size_gib: builtins.int
    """Size of a single disk drive in gibibytes (2^30 bytes)."""
    def __init__(
        self,
        *,
        type: yandex.cloud.baremetal.v1alpha.disk_pb2.DiskDriveType.ValueType = ...,
        disk_count: builtins.int = ...,
        disk_size_gib: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_count", b"disk_count", "disk_size_gib", b"disk_size_gib", "type", b"type"]) -> None: ...

global___DiskDriveConfiguration = DiskDriveConfiguration

@typing.final
class Configuration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MEMORY_GIB_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    DISK_DRIVES_FIELD_NUMBER: builtins.int
    NETWORK_CAPACITY_GBPS_FIELD_NUMBER: builtins.int
    CPU_NUM_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the configuration."""
    name: builtins.str
    """Name of the configuration."""
    memory_gib: builtins.int
    """Random-access memory (RAM) size in gibibytes (2^30 bytes)."""
    network_capacity_gbps: builtins.int
    """Network capacity or bandwidth in gigabits per second."""
    cpu_num: builtins.int
    """Number of cpu."""
    @property
    def cpu(self) -> global___CPU:
        """CPU configuration."""

    @property
    def disk_drives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DiskDriveConfiguration]:
        """Array of disk drive configurations."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        memory_gib: builtins.int = ...,
        cpu: global___CPU | None = ...,
        disk_drives: collections.abc.Iterable[global___DiskDriveConfiguration] | None = ...,
        network_capacity_gbps: builtins.int = ...,
        cpu_num: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cpu", b"cpu"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cpu", b"cpu", "cpu_num", b"cpu_num", "disk_drives", b"disk_drives", "id", b"id", "memory_gib", b"memory_gib", "name", b"name", "network_capacity_gbps", b"network_capacity_gbps"]) -> None: ...

global___Configuration = Configuration



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.oauth_client_pb2
import yandex.cloud.iam.v1.oauth_client_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class OAuthClientServiceStub:
    """A set of methods for managing OAuthClient resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.GetOAuthClientRequest,
        yandex.cloud.iam.v1.oauth_client_pb2.OAuthClient,
    ]
    """Returns the sepcified OAuthClient resource.

    To get the list of available OAuthClient resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.ListOAuthClientsRequest,
        yandex.cloud.iam.v1.oauth_client_service_pb2.ListOAuthClientsResponse,
    ]
    """Retrieves the list of OAuthClient resources views in the specified folder"""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.CreateOAuthClientRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an oauth client in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.UpdateOAuthClientRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified oauth client."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.DeleteOAuthClientRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified oauth client with all its secrets."""

class OAuthClientServiceAsyncStub:
    """A set of methods for managing OAuthClient resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.GetOAuthClientRequest,
        yandex.cloud.iam.v1.oauth_client_pb2.OAuthClient,
    ]
    """Returns the sepcified OAuthClient resource.

    To get the list of available OAuthClient resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.ListOAuthClientsRequest,
        yandex.cloud.iam.v1.oauth_client_service_pb2.ListOAuthClientsResponse,
    ]
    """Retrieves the list of OAuthClient resources views in the specified folder"""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.CreateOAuthClientRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an oauth client in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.UpdateOAuthClientRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified oauth client."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_service_pb2.DeleteOAuthClientRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified oauth client with all its secrets."""

class OAuthClientServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing OAuthClient resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iam.v1.oauth_client_service_pb2.GetOAuthClientRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.oauth_client_pb2.OAuthClient, collections.abc.Awaitable[yandex.cloud.iam.v1.oauth_client_pb2.OAuthClient]]:
        """Returns the sepcified OAuthClient resource.

        To get the list of available OAuthClient resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iam.v1.oauth_client_service_pb2.ListOAuthClientsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.oauth_client_service_pb2.ListOAuthClientsResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.oauth_client_service_pb2.ListOAuthClientsResponse]]:
        """Retrieves the list of OAuthClient resources views in the specified folder"""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iam.v1.oauth_client_service_pb2.CreateOAuthClientRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an oauth client in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.iam.v1.oauth_client_service_pb2.UpdateOAuthClientRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified oauth client."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iam.v1.oauth_client_service_pb2.DeleteOAuthClientRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified oauth client with all its secrets."""

def add_OAuthClientServiceServicer_to_server(servicer: OAuthClientServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2
import yandex.cloud.marketplace.licensemanager.v1.lock_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class LockServiceStub:
    """A set of methods for managing subscription locks."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Ensure: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.EnsureLockRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Checks if the she specified subscription is already locked to the specified resource.
    If it is not locked, locks the subscription to the resource.
    """

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.GetLockRequest,
        yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock,
    ]
    """Returns the specified subscription lock."""

    GetByResourceID: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.GetLockByResourceIDRequest,
        yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock,
    ]
    """Returns the subscription lock for given resource and subscription."""

class LockServiceAsyncStub:
    """A set of methods for managing subscription locks."""

    Ensure: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.EnsureLockRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Checks if the she specified subscription is already locked to the specified resource.
    If it is not locked, locks the subscription to the resource.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.GetLockRequest,
        yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock,
    ]
    """Returns the specified subscription lock."""

    GetByResourceID: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.GetLockByResourceIDRequest,
        yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock,
    ]
    """Returns the subscription lock for given resource and subscription."""

class LockServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing subscription locks."""

    @abc.abstractmethod
    def Ensure(
        self,
        request: yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.EnsureLockRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Checks if the she specified subscription is already locked to the specified resource.
        If it is not locked, locks the subscription to the resource.
        """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.GetLockRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock, collections.abc.Awaitable[yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock]]:
        """Returns the specified subscription lock."""

    @abc.abstractmethod
    def GetByResourceID(
        self,
        request: yandex.cloud.marketplace.licensemanager.saas.v1.lock_service_pb2.GetLockByResourceIDRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock, collections.abc.Awaitable[yandex.cloud.marketplace.licensemanager.v1.lock_pb2.Lock]]:
        """Returns the subscription lock for given resource and subscription."""

def add_LockServiceServicer_to_server(servicer: LockServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.assistants.v1.runs import run_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2
from yandex.cloud.ai.assistants.v1.runs import run_service_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/assistants/v1/runs/run_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class RunServiceStub(object):
    """RunService provides operations for managing runs.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.ai.assistants.v1.runs.RunService/Create',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.CreateRunRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.FromString,
                _registered_method=True)
        self.Listen = channel.unary_stream(
                '/yandex.cloud.ai.assistants.v1.runs.RunService/Listen',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListenRunRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.StreamEvent.FromString,
                _registered_method=True)
        self.Attach = channel.stream_stream(
                '/yandex.cloud.ai.assistants.v1.runs.RunService/Attach',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.AttachRunRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.StreamEvent.FromString,
                _registered_method=True)
        self.Get = channel.unary_unary(
                '/yandex.cloud.ai.assistants.v1.runs.RunService/Get',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.GetRunRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.FromString,
                _registered_method=True)
        self.GetLastByThread = channel.unary_unary(
                '/yandex.cloud.ai.assistants.v1.runs.RunService/GetLastByThread',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.GetLastRunByThreadRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.ai.assistants.v1.runs.RunService/List',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListRunsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListRunsResponse.FromString,
                _registered_method=True)
        self.Submit = channel.unary_unary(
                '/yandex.cloud.ai.assistants.v1.runs.RunService/Submit',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.SubmitToRunRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.SubmitToRunResponse.FromString,
                _registered_method=True)


class RunServiceServicer(object):
    """RunService provides operations for managing runs.
    """

    def Create(self, request, context):
        """Create a new run for a given assistant and thread.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Listen(self, request, context):
        """Listen to events from a specific run.
        If the run was created with `stream = false`, Listen will only respond with the final status of the run
        and will not stream partial messages or intermediate events.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Attach(self, request_iterator, context):
        """Bi-directional streaming method to interact with a specific run.
        Like `Listen`, `Attach` streams events from the run, but also allows clients to send events back.
        For example, it can be used to submit function call results when the run is waiting for user input.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Retrieve details of a specific run by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLastByThread(self, request, context):
        """Retrieves the most recent run for a specific thread.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """List runs in a specific folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Submit(self, request, context):
        """Submit event to run
        For example, submit function call results when the run is waiting for user input.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.CreateRunRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.SerializeToString,
            ),
            'Listen': grpc.unary_stream_rpc_method_handler(
                    servicer.Listen,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListenRunRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.StreamEvent.SerializeToString,
            ),
            'Attach': grpc.stream_stream_rpc_method_handler(
                    servicer.Attach,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.AttachRunRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.StreamEvent.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.GetRunRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.SerializeToString,
            ),
            'GetLastByThread': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLastByThread,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.GetLastRunByThreadRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListRunsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListRunsResponse.SerializeToString,
            ),
            'Submit': grpc.unary_unary_rpc_method_handler(
                    servicer.Submit,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.SubmitToRunRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.SubmitToRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.assistants.v1.runs.RunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.ai.assistants.v1.runs.RunService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class RunService(object):
    """RunService provides operations for managing runs.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.assistants.v1.runs.RunService/Create',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.CreateRunRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Listen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/yandex.cloud.ai.assistants.v1.runs.RunService/Listen',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListenRunRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.StreamEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Attach(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/yandex.cloud.ai.assistants.v1.runs.RunService/Attach',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.AttachRunRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.StreamEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.assistants.v1.runs.RunService/Get',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.GetRunRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLastByThread(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.assistants.v1.runs.RunService/GetLastByThread',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.GetLastRunByThreadRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2.Run.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.assistants.v1.runs.RunService/List',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListRunsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.ListRunsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Submit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.assistants.v1.runs.RunService/Submit',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.SubmitToRunRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__service__pb2.SubmitToRunResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/public_subnet_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/public_subnet_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.baremetal.v1alpha import public_subnet_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_public__subnet__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/baremetal/v1alpha/public_subnet_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x32yandex/cloud/baremetal/v1alpha/public_subnet.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x16GetPublicSubnetRequest\x12\x1e\n\x10public_subnet_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xa4\x01\n\x17ListPublicSubnetRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"\x7f\n\x18ListPublicSubnetResponse\x12\x44\n\x0epublic_subnets\x18\x01 \x03(\x0b\x32,.yandex.cloud.baremetal.v1alpha.PublicSubnet\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xab\x03\n\x19\x43reatePublicSubnetRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x19\n\x11hardware_pool_ids\x18\x04 \x03(\t\x12\x1f\n\rprefix_length\x18\x05 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x31-31\x12\x93\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x45.yandex.cloud.baremetal.v1alpha.CreatePublicSubnetRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x06\x10\xc8\x01\"6\n\x1a\x43reatePublicSubnetMetadata\x12\x18\n\x10public_subnet_id\x18\x01 \x01(\t\"\xea\x03\n\x19UpdatePublicSubnetRequest\x12\x1e\n\x10public_subnet_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x19\n\x11hardware_pool_ids\x18\x05 \x03(\t\x12>\n\x04type\x18\x06 \x01(\x0e\x32\x30.yandex.cloud.baremetal.v1alpha.PublicSubnetType\x12\x93\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x45.yandex.cloud.baremetal.v1alpha.UpdatePublicSubnetRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x07\x10\xc8\x01\"6\n\x1aUpdatePublicSubnetMetadata\x12\x18\n\x10public_subnet_id\x18\x01 \x01(\t\";\n\x19\x44\x65letePublicSubnetRequest\x12\x1e\n\x10public_subnet_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1a\x44\x65letePublicSubnetMetadata\x12\x18\n\x10public_subnet_id\x18\x01 \x01(\t\"u\n!ListPublicSubnetOperationsRequest\x12\x18\n\x10public_subnet_id\x18\x01 \x01(\t\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x02\x10\x64\"z\n\"ListPublicSubnetOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xc0\t\n\x13PublicSubnetService\x12\xa8\x01\n\x03Get\x12\x36.yandex.cloud.baremetal.v1alpha.GetPublicSubnetRequest\x1a,.yandex.cloud.baremetal.v1alpha.PublicSubnet\";\x82\xd3\xe4\x93\x02\x35\x12\x33/baremetal/v1alpha/publicSubnets/{public_subnet_id}\x12\xa3\x01\n\x04List\x12\x37.yandex.cloud.baremetal.v1alpha.ListPublicSubnetRequest\x1a\x38.yandex.cloud.baremetal.v1alpha.ListPublicSubnetResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /baremetal/v1alpha/publicSubnets\x12\xc1\x01\n\x06\x43reate\x12\x39.yandex.cloud.baremetal.v1alpha.CreatePublicSubnetRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2**\n\x1a\x43reatePublicSubnetMetadata\x12\x0cPublicSubnet\x82\xd3\xe4\x93\x02%\" /baremetal/v1alpha/publicSubnets:\x01*\x12\xd4\x01\n\x06Update\x12\x39.yandex.cloud.baremetal.v1alpha.UpdatePublicSubnetRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2**\n\x1aUpdatePublicSubnetMetadata\x12\x0cPublicSubnet\x82\xd3\xe4\x93\x02\x38\x32\x33/baremetal/v1alpha/publicSubnets/{public_subnet_id}:\x01*\x12\xda\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.baremetal.v1alpha.DeletePublicSubnetRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*3\n\x1a\x44\x65letePublicSubnetMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x35*3/baremetal/v1alpha/publicSubnets/{public_subnet_id}\x12\xdf\x01\n\x0eListOperations\x12\x41.yandex.cloud.baremetal.v1alpha.ListPublicSubnetOperationsRequest\x1a\x42.yandex.cloud.baremetal.v1alpha.ListPublicSubnetOperationsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/baremetal/v1alpha/publicSubnets/{public_subnet_id}/operationsBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.public_subnet_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETPUBLICSUBNETREQUEST'].fields_by_name['public_subnet_id']._loaded_options = None
  _globals['_GETPUBLICSUBNETREQUEST'].fields_by_name['public_subnet_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTPUBLICSUBNETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTPUBLICSUBNETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_LISTPUBLICSUBNETREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPUBLICSUBNETREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_CREATEPUBLICSUBNETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEPUBLICSUBNETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['prefix_length']._loaded_options = None
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['prefix_length']._serialized_options = b'\372\3071\0041-31'
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEPUBLICSUBNETREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEPUBLICSUBNETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEPUBLICSUBNETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['public_subnet_id']._loaded_options = None
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['public_subnet_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEPUBLICSUBNETREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEPUBLICSUBNETREQUEST'].fields_by_name['public_subnet_id']._loaded_options = None
  _globals['_DELETEPUBLICSUBNETREQUEST'].fields_by_name['public_subnet_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTPUBLICSUBNETOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPUBLICSUBNETOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0025\0223/baremetal/v1alpha/publicSubnets/{public_subnet_id}'
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /baremetal/v1alpha/publicSubnets'
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreatePublicSubnetMetadata\022\014PublicSubnet\202\323\344\223\002%\" /baremetal/v1alpha/publicSubnets:\001*'
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdatePublicSubnetMetadata\022\014PublicSubnet\202\323\344\223\002823/baremetal/v1alpha/publicSubnets/{public_subnet_id}:\001*'
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeletePublicSubnetMetadata\022\025google.protobuf.Empty\202\323\344\223\0025*3/baremetal/v1alpha/publicSubnets/{public_subnet_id}'
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_PUBLICSUBNETSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002@\022>/baremetal/v1alpha/publicSubnets/{public_subnet_id}/operations'
  _globals['_GETPUBLICSUBNETREQUEST']._serialized_start=315
  _globals['_GETPUBLICSUBNETREQUEST']._serialized_end=371
  _globals['_LISTPUBLICSUBNETREQUEST']._serialized_start=374
  _globals['_LISTPUBLICSUBNETREQUEST']._serialized_end=538
  _globals['_LISTPUBLICSUBNETRESPONSE']._serialized_start=540
  _globals['_LISTPUBLICSUBNETRESPONSE']._serialized_end=667
  _globals['_CREATEPUBLICSUBNETREQUEST']._serialized_start=670
  _globals['_CREATEPUBLICSUBNETREQUEST']._serialized_end=1097
  _globals['_CREATEPUBLICSUBNETREQUEST_LABELSENTRY']._serialized_start=1045
  _globals['_CREATEPUBLICSUBNETREQUEST_LABELSENTRY']._serialized_end=1090
  _globals['_CREATEPUBLICSUBNETMETADATA']._serialized_start=1099
  _globals['_CREATEPUBLICSUBNETMETADATA']._serialized_end=1153
  _globals['_UPDATEPUBLICSUBNETREQUEST']._serialized_start=1156
  _globals['_UPDATEPUBLICSUBNETREQUEST']._serialized_end=1646
  _globals['_UPDATEPUBLICSUBNETREQUEST_LABELSENTRY']._serialized_start=1045
  _globals['_UPDATEPUBLICSUBNETREQUEST_LABELSENTRY']._serialized_end=1090
  _globals['_UPDATEPUBLICSUBNETMETADATA']._serialized_start=1648
  _globals['_UPDATEPUBLICSUBNETMETADATA']._serialized_end=1702
  _globals['_DELETEPUBLICSUBNETREQUEST']._serialized_start=1704
  _globals['_DELETEPUBLICSUBNETREQUEST']._serialized_end=1763
  _globals['_DELETEPUBLICSUBNETMETADATA']._serialized_start=1765
  _globals['_DELETEPUBLICSUBNETMETADATA']._serialized_end=1819
  _globals['_LISTPUBLICSUBNETOPERATIONSREQUEST']._serialized_start=1821
  _globals['_LISTPUBLICSUBNETOPERATIONSREQUEST']._serialized_end=1938
  _globals['_LISTPUBLICSUBNETOPERATIONSRESPONSE']._serialized_start=1940
  _globals['_LISTPUBLICSUBNETOPERATIONSRESPONSE']._serialized_end=2062
  _globals['_PUBLICSUBNETSERVICE']._serialized_start=2065
  _globals['_PUBLICSUBNETSERVICE']._serialized_end=3281
# @@protoc_insertion_point(module_scope)
